@@ -3,8 +3,7 @@
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 """Requirement provider interfaces."""
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 import functools
 import typing as t
@@ -40,6 +39,7 @@ except ImportError:
 
 # TODO: add python requirements to ansible-test's ansible-core distribution info and remove the hardcoded lowerbound/upperbound fallback
 RESOLVELIB_LOWERBOUND = SemanticVersion("0.5.3")
+RESOLVELIB_UPPERBOUND = SemanticVersion("1.1.1")
 RESOLVELIB_VERSION = SemanticVersion.from_loose_version(LooseVersion(resolvelib_version))
 
 
@@ -126,7 +126,7 @@ class CollectionDependencyProviderBase(AbstractProvider):
             the current candidate list
 
           * ``parent`` specifies the candidate that provides
-            (dependend on) the requirement, or `None`
+            (depended on) the requirement, or `None`
             to indicate a root requirement.
 
         resolvelib >=0.7.0, < 0.8.0
@@ -135,14 +135,14 @@ class CollectionDependencyProviderBase(AbstractProvider):
 
         :param resolutions: Mapping of identifier, candidate pairs.
 
-        :param candidates: Possible candidates for the identifer.
+        :param candidates: Possible candidates for the identifier.
             Mapping of identifier, list of candidate pairs.
 
         :param information: Requirement information of each package.
             Mapping of identifier, list of named tuple pairs.
             The named tuples have the entries ``requirement`` and ``parent``.
 
-        resolvelib >=0.8.0
+        resolvelib >=0.8.0, <= 1.0.1
 
         :param identifier: The value returned by ``identify()``.
 
@@ -202,7 +202,7 @@ class CollectionDependencyProviderBase(AbstractProvider):
         remote archives), the one-and-only match is returned
 
         For a "named" requirement, Galaxy-compatible APIs are consulted
-        to find concrete candidates for this requirement. Of theres a
+        to find concrete candidates for this requirement. If there's a
         pre-installed candidate, it's prepended in front of others.
 
         resolvelib >=0.5.3, <0.6.0
@@ -437,12 +437,12 @@ class CollectionDependencyProviderBase(AbstractProvider):
         # FIXME: differs. So how do we resolve this case? Priority?
         # FIXME: Taking into account a pinned hash? Exploding on
         # FIXME: any differences?
-        # NOTE: The underlying implmentation currently uses first found
+        # NOTE: The underlying implementation currently uses first found
         req_map = self._api_proxy.get_collection_dependencies(candidate)
 
         # NOTE: This guard expression MUST perform an early exit only
         # NOTE: after the `get_collection_dependencies()` call because
-        # NOTE: internally it polulates the artifact URL of the candidate,
+        # NOTE: internally it populates the artifact URL of the candidate,
         # NOTE: its SHA hash and the Galaxy API token. These are still
         # NOTE: necessary with `--no-deps` because even with the disabled
         # NOTE: dependency resolution the outer layer will still need to
